"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFixtureUrls = getFixtureUrls;

var _react = require("react-cosmos-shared2/react");

var _url = require("react-cosmos-shared2/url");

var _userDeps = require("./shared/userDeps");

async function getFixtureUrls({
  cosmosConfig,
  fullScreen = false
}) {
  const host = getPlaygroundHost(cosmosConfig);
  const fixtureUrls = [];

  function pushFixtureUrl(fixtureId) {
    fixtureUrls.push(createFixtureUrl(host, fixtureId, fullScreen));
  }

  const {
    fixtureExportsByPath
  } = await (0, _userDeps.getUserModules)(cosmosConfig);
  const fixtureNamesByPath = (0, _react.getFixtureNamesByPath)(fixtureExportsByPath);
  Object.keys(fixtureNamesByPath).forEach(fixturePath => {
    const fixtureNames = fixtureNamesByPath[fixturePath];

    if (fixtureNames === null) {
      pushFixtureUrl({
        path: fixturePath,
        name: null
      });
    } else {
      fixtureNames.forEach(fixtureName => {
        pushFixtureUrl({
          path: fixturePath,
          name: fixtureName
        });
      });
    }
  });
  return fixtureUrls;
}

function createFixtureUrl(host, fixtureId, fullScreen) {
  const urlParams = {
    fixtureId
  };

  if (fullScreen) {
    urlParams.fullScreen = true;
  }

  return `${host}/?${(0, _url.stringifyPlaygroundUrlQuery)(urlParams)}`;
}

function getPlaygroundHost({
  hostname,
  port
}) {
  return `${hostname || 'localhost'}:${port}`;
}